@@ -8,16 +8,18 @@ from seldon_deploy_sdk.api.application_logs_api import ApplicationLogsApi
 from seldon_deploy_sdk.api.batch_jobs_api import BatchJobsApi
 from seldon_deploy_sdk.api.drift_detector_api import DriftDetectorApi
 from seldon_deploy_sdk.api.environment_api import EnvironmentApi
+from seldon_deploy_sdk.api.experiments_api import ExperimentsApi
 from seldon_deploy_sdk.api.explain_api import ExplainApi
 from seldon_deploy_sdk.api.git_ops_api import GitOpsApi
-from seldon_deploy_sdk.api.inference_services_api import InferenceServicesApi
 from seldon_deploy_sdk.api.kubernetes_resources_api import KubernetesResourcesApi
 from seldon_deploy_sdk.api.loadtest_jobs_api import LoadtestJobsApi
 from seldon_deploy_sdk.api.metrics_server_api import MetricsServerApi
 from seldon_deploy_sdk.api.model_metadata_service_api import ModelMetadataServiceApi
+from seldon_deploy_sdk.api.models_api import ModelsApi
 from seldon_deploy_sdk.api.monitor_api import MonitorApi
 from seldon_deploy_sdk.api.outlier_detector_api import OutlierDetectorApi
 from seldon_deploy_sdk.api.permission_management_service_api import PermissionManagementServiceApi
+from seldon_deploy_sdk.api.pipelines_api import PipelinesApi
 from seldon_deploy_sdk.api.predict_api import PredictApi
 from seldon_deploy_sdk.api.secrets_service_api import SecretsServiceApi
 from seldon_deploy_sdk.api.seldon_deployments_api import SeldonDeploymentsApi
